These are examples of alternative templates for report generation. 

Each template is formatted using a list under "sections" of dictionaries. 

Each dictionary needs a "section" field whose value is the name of a public method in  Report.py.